## Grafica

Un tema para [Sphinx][sphinx] adaptado del diseño de https://www.gob.mx.

En particular, se utilizó la [guía de estilo][guia] como referencia.


## Configuración

- `description`: Descripción corta del proyecto que
               se muestra al pie de página.
- `github_repo`: Nombre del repositorio de GitHub al que se enlaza.
- `github_user`: Usuario de GitHub en el que existe el repositorio.
- `twitter_user`: Handle de twitter al que se enlaza
                  en el pie de página.
- `instagram_user`: Handle de instagram al que se enlaza
                    en el pie de página.
- `youtube_user`: Handle de youtube al que se enlaza
                  en el pie de página.
- `extra_nav_links`: Diccionario con nombres y URLs de
                     enlaces a mostrar en el pie de página.


## Licencia

Este tema se proporciona bajo la licencia BSD de 3 cláusulas (3-Clause BSD).

El diseño de https://www.gob.mx/ es propiedad intelectual de sus autores.

[sphinx]: https://www.sphinx-doc.org/
[guia]: https://framework-gb.cdn.gob.mx/
